<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="88"/>
        <source>Version: %1</source>
        <translation>Phiên bản: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Một môi trường cho máy tính để bàn nhanh nhạy, dễ sử dụng và đầy tính năng dựa trên công nghệ Qt.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="106"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>LXQt sẽ không thể được thực hiện nếu không có dự án &lt;a %1&gt;Razor-qt&lt;/a&gt; và những người đóng góp của nó.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="108"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Bản quyền: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="110"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Trang chủ: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="112"/>
        <source>Wiki: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Wiki: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>Development: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Phát triển: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Giấy phép: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="126"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>LXQt được phát triển bởi &lt;a %1&gt;Team LXQt và những người đóng góp&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="128"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>Nếu bạn hứng thú với chuyện làm việc với team phát triển của chúng tôi, &lt;a %1&gt;hãy tham gia&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="145"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>Lời cảm ơn đặc biệt đến:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="152"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt được dịch sang nhiều ngôn ngữ nhờ công sức của các team thông dịch khắp thế giới. Việc dịch có thể được thực hiện tại &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>Sao chép vào bộ nhớ đệm</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation>Về LXQt</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>Về</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>Tác giả</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>Cảm ơn</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>Bản dịch</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>Thông tin kĩ thuật</translation>
    </message>
</context>
</TS>
